## 3.2.8.20260225 (2026-02-25)

[stubsabot] Bump ibm-db to 3.2.8 ([#14685](https://github.com/python/typeshed/pull/14685))

## 3.2.6.20250311 (2025-03-11)

[stubsabot] Bump ibm-db to 3.2.6 ([#13610](https://github.com/python/typeshed/pull/13610))

## 3.2.5.20241231 (2024-12-31)

[stubsabot] Bump ibm-db to 3.2.5 ([#13348](https://github.com/python/typeshed/pull/13348))

Release: https://pypi.org/pypi/ibm-db/3.2.5
Homepage: http://pypi.python.org/pypi/ibm_db/
Repository: https://github.com/ibmdb/python-ibmdb
Typeshed stubs: https://github.com/python/typeshed/tree/main/stubs/ibm-db
Diff: https://github.com/ibmdb/python-ibmdb/compare/v3.2.4...v3.2.5

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 13.
 - Total lines of Python code deleted: 9.

## 3.2.4.20241216 (2024-12-16)

Bump ibm-db to 3.2.4 ([#13251](https://github.com/python/typeshed/pull/13251))

## 3.2.3.20241212 (2024-12-12)

pin ibm-db to 3.2.3 ([#13233](https://github.com/python/typeshed/pull/13233))

## 3.2.0.20241204 (2024-12-04)

Remove obsolete todo from `ibm_db.pyi` ([#13170](https://github.com/python/typeshed/pull/13170))

The `SQL_ATTR_CONFIG_KEYWORDS_MAXLEN` attr is already there on line 100

## 3.2.0.20240311 (2024-03-11)

Use PEP 570 syntax in third party stubs ([#11554](https://github.com/python/typeshed/pull/11554))

## 3.2.0.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs ([#11245](https://github.com/python/typeshed/pull/11245))

## 3.2.0.1 (2023-11-24)

ibm-db: Add SQL_ATTR_TXN_ISOLATION ([#11060](https://github.com/python/typeshed/pull/11060))

## 3.2.0.0 (2023-08-27)

Update `ibm-db` to `3.2.*` ([#10622](https://github.com/python/typeshed/pull/10622))

## 3.1.0.3 (2023-08-13)

Fill in all missing `upstream_repository` fields ([#10571](https://github.com/python/typeshed/pull/10571))

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 3.1.0.2 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` ([#9779](https://github.com/python/typeshed/pull/9779))

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 3.1.0.1 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` ([#9702](https://github.com/python/typeshed/pull/9702))

## 3.1.0.0 (2022-12-24)

Add stub for ibm_db ([#9325](https://github.com/python/typeshed/pull/9325))

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

